Changelog
=========

Unreleased
----------


Added
~~~~~~~~~~~~~~~~~~~~~

- Short json parameter

- (cli) More parameters

- Improve lang option

- Improved list-addons command

- Addon path manager and manifest_collection has been added

- Add tree option

- Add depth parameter

- New parameter

- Add manifestoo-core

- Detect odoo series

- Add sorting modules

- Do not repeat version in tree

- Improved tree layout

- List-missing added to cli

- Exclude addons beginning with test_ and allow to exclude core and enterprise addons



Fixed
~~~~~~~~~~~~~~~~~~~~~

- (cli) Add error message

- Codepends



Documentation
~~~~~~~~~~~~~~~~~~~~~

- Improve readme and doc, adding more urls to project

- Fix api doc links

- Improve doc with no-index

- Add new classes



Miscellaneous
~~~~~~~~~~~~~~~~~~~~~

- Fix doc build

- Fix link

- Fix pre-commit

- Fix static type checker mypy


0.1.6
----------


Added
~~~~~~~~~~~~~~~~~~~~~

- (config) Improved get_odoo_params_list



Documentation
~~~~~~~~~~~~~~~~~~~~~

- Automatically generate changelog through cliff

- Add pypi badge


0.1.5
----------


Fixed
~~~~~~~~~~~~~~~~~~~~~

- Db params need a underscore


0.1.4
----------


Added
~~~~~~~~~~~~~~~~~~~~~

- Better help screen for cli tool

- (db) Move drop_db into own function


0.1.3
----------


Fixed
~~~~~~~~~~~~~~~~~~~~~

- List-db was printed twice



Testing
~~~~~~~~~~~~~~~~~~~~~

- Fix path on windows


0.1.2
----------


Added
~~~~~~~~~~~~~~~~~~~~~

- (db) List db added



Fixed
~~~~~~~~~~~~~~~~~~~~~

- Path for windows

- Use a more robust approach


0.1.1
----------


Added
~~~~~~~~~~~~~~~~~~~~~

- (db) Allow drop_db and create_db without sudo



Documentation
~~~~~~~~~~~~~~~~~~~~~

- Fix build

- Fix documentation



Testing
~~~~~~~~~~~~~~~~~~~~~

- Update codecov



Miscellaneous
~~~~~~~~~~~~~~~~~~~~~

- Add codecov workflow

- Add readthedocs.yml

- Fix pre-commit

- Fix actions

- Add codecov badge


0.1.0
----------


Fixed
~~~~~~~~~~~~~~~~~~~~~

- Not working parameter in install removed



Documentation
~~~~~~~~~~~~~~~~~~~~~

- Add cli doc



Refactor
~~~~~~~~~~~~~~~~~~~~~

- Remove obsolete function from config_loader



Miscellaneous
~~~~~~~~~~~~~~~~~~~~~

- Initial release

- Pre-commit and readme cleanup
